==> xrumaplib-0.1.tar.gz: xrumaplib-0.1/setup.py <==
from distutils.core import setup
setup(
  name = 'xrumaplib',         # How you named your package folder (MyLib)
  packages = ['xrumaplib'],   # Chose the same as "name"
  version = '0.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Nonlinear dimensionality reduction for a xarray datasets',   # Give a short description about your library
  author = 'meteoia-team',                   # Type in your name
  author_email = 'meteoai.consult@gmail.clm',      # Type in your E-Mail
  url = 'https://github.com/user/reponame',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/meteoia-team/xarray-umap/archive/0.1.tar.gz',    # I explain this later on
  keywords = ['xarray', 'umap', 'encoder','dimensionality'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'xarray',
          'keras',
          'umap'
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package

    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',

    'License :: OSI Approved :: MIT License',   # Again, pick a license

    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)

==> xrumaplib-0.12.tar.gz: xrumaplib-0.12/setup.py <==
from distutils.core import setup
setup(
  name = 'xrumaplib',         # How you named your package folder (MyLib)
  packages = ['xrumaplib'],   # Chose the same as "name"
  version = '0.12',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Nonlinear dimensionality reduction for a xarray datasets',   # Give a short description about your library
  author = 'meteoia-team',                   # Type in your name
  author_email = 'meteoai.consult@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/user/reponame',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/meteoia-team/xarray-umap/archive/0.12.tar.gz',    # I explain this later on
  keywords = ['xarray', 'umap', 'encoder','dimensionality'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'xarray',
          'keras',
          'umap-learn'
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package

    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',

    'License :: OSI Approved :: MIT License',   # Again, pick a license

    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
